#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Mar  6 15:58:07 2019

@author: ltetrel
"""

import unittest
import shutil
import os
from repo2data.repo2data import Repo2Data

class Test(unittest.TestCase):
    def test_multiple(self):
        if os.path.exists("./tests/out/repo2data_multiple1"):
            shutil.rmtree("./tests/out/repo2data_multiple1")
        if os.path.exists("./tests/out/repo2data_multiple2"):
            shutil.rmtree("./tests/out/repo2data_multiple2")
        repo2data = Repo2Data("./tests/in/multiple.json")
        repo2data.install()
        self.assertTrue(os.path.exists("./tests/out/repo2data_multiple1/AUTHORS"))
        self.assertTrue(os.path.exists("./tests/out/repo2data_multiple1/data_requirement.json"))
        self.assertTrue(os.path.exists("./tests/out/repo2data_multiple2/LICENSE"))
        self.assertTrue(os.path.exists("./tests/out/repo2data_multiple2/data_requirement.json"))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Mar  6 15:58:07 2019

@author: ltetrel
"""

import unittest
import shutil
import os
from repo2data.repo2data import Repo2Data

class Test(unittest.TestCase):
    def test_neurolibre_layout(self):
        data_req_path = "./tests/in/neurolibre/binder/neurolibre_layout.json"
        if os.path.exists("./tests/in/neurolibre/data/repo2data_neurolibre_layout"):
            shutil.rmtree("./tests/in/neurolibre/data/repo2data_neurolibre_layout")
        repo2data = Repo2Data(data_req_path)
        data_path = repo2data.install()[0]
        print(data_path)
        self.assertTrue(len(os.listdir(data_path)) > 1)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Mar  6 15:58:07 2019

@author: ltetrel
"""

import unittest
import shutil
import os
import json
from repo2data.repo2data import Repo2Data

class Test(unittest.TestCase):
    def test_osf(self):
        data_req_path = "./tests/in/zenodo.json"
        with open(data_req_path, "r") as f:
            data_req = json.load(f)
        dir_path = os.path.join(data_req["dst"], data_req["projectName"])
        if os.path.exists(dir_path):
            shutil.rmtree(dir_path)
            
        repo2data = Repo2Data(data_req_path)
        repo2data.install()
        dirs = os.listdir(dir_path)
        self.assertTrue(len(dirs) > 1)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Jan 28 09:58:27 2019

@author: ltetrel
"""

import argparse
from repo2data.repo2data import Repo2Data
import repo2data.utils

def get_parser():
    parser = argparse.ArgumentParser(
            formatter_class=argparse.RawDescriptionHelpFormatter
            , description=""
            , epilog="""
            Documentation at https://github.com/SIMEXP/Repo2Data
            """)

    parser.add_argument(
            "-r"
            , "--data_requirement"
            , required=False
            , default=None
            , help="Data requirement file (can be a https://github repo), Default: current directory",
            )
    
    parser.add_argument(
            "--server"
            , action="store_true"
            , required=False
            , default=False
            , help="Disabling the dst option for the user, Default: False",
            )

    parser.add_argument(
            "--version"
            , action="version"
            , version=repo2data.utils.get_version()
            )

#    parser.add_argument(
#            "-l"
#            , "--log_level"
#            , required=False
#            , default="INFO"
#            , choices=["DEBUG","INFO","WARNING","ERROR","CRITICAL"]
#            , help="Set logging level",
#            )
   
    return parser

def main():
    args = get_parser().parse_args()
    repo2data = Repo2Data(**vars(args))
    repo2data.install()
    
if __name__ == '__main__':
    main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Mar  24 13:01:08 2020

@author: ltetrel
"""

import unittest
import shutil
import os
from repo2data.repo2data import Repo2Data

class Test(unittest.TestCase):
    def test_url(self):
        dir_path = "./data/repo2data_s3_binder"
        if os.path.exists(dir_path):
            shutil.rmtree(dir_path)
        repo2data = Repo2Data("https://github.com/ltetrel/repo2data-caching-s3")
        repo2data.install()
        dirs = os.listdir(dir_path)
        self.assertTrue(len(dirs) > 1)


# -*- coding: utf-8 -*-

import os
import hashlib

def dirhash(dirname):
    hash_func = hashlib.sha256

    if not os.path.isdir(dirname):
        raise TypeError('{} is not a directory.'.format(dirname))
    hashvalues = []
    for root, dirs, files in os.walk(dirname, topdown=True):
        hashvalues.extend(
            [
                _filehash(os.path.join(root, f), hash_func) 
                for f in files
            ]
        )
    return _reduce_hash(hashvalues, hash_func)


def _filehash(filepath, hashfunc):
    hasher = hashfunc()
    blocksize = 64 * 1024
    with open(filepath, 'rb') as fp:
        while True:
            data = fp.read(blocksize)
            if not data:
                break
            hasher.update(data)
    return hasher.hexdigest()


def _reduce_hash(hashlist, hashfunc):
    hasher = hashfunc()
    for hashvalue in sorted(hashlist):
        hasher.update(hashvalue.encode('utf-8'))
    return hasher.hexdigest()